@@ -86,34 +86,28 @@ p, li { white-space: pre-wrap; }
 <context>
     <name>RouteSearchWindow</name>
     <message>
-        <location filename="routesearchwindow.ui" line="14"/>
         <source>Route Search</source>
-        <translation>Rutesøk</translation>
+        <translation type="obsolete">Rutesøk</translation>
     </message>
     <message>
-        <location filename="routesearchwindow.ui" line="38"/>
         <source>From:</source>
-        <translation>Fra:</translation>
+        <translation type="obsolete">Fra:</translation>
     </message>
     <message>
-        <location filename="routesearchwindow.ui" line="45"/>
-        <location filename="routesearchwindow.ui" line="59"/>
         <source>Search for place</source>
-        <translation>Søk etter sted</translation>
+        <translation type="obsolete">Søk etter sted</translation>
     </message>
     <message>
         <source>Click to select station</source>
         <translation type="obsolete">Klikk for å velge stasjon</translation>
     </message>
     <message>
-        <location filename="routesearchwindow.ui" line="52"/>
         <source>To:</source>
-        <translation>Til:</translation>
+        <translation type="obsolete">Til:</translation>
     </message>
     <message>
-        <location filename="routesearchwindow.ui" line="68"/>
         <source>Search</source>
-        <translation>Søk</translation>
+        <translation type="obsolete">Søk</translation>
     </message>
     <message>
         <source>Routing info is not yet available</source>
@@ -165,7 +159,8 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <location filename="trafikantenwindow.ui" line="114"/>
-        <source>Find route</source>
+        <source>Find travel</source>
+        <oldsource>Find route</oldsource>
         <translation>Finn rute</translation>
     </message>
     <message>
@@ -191,7 +186,7 @@ p, li { white-space: pre-wrap; }
     <message>
         <location filename="trafikantenwindow.ui" line="202"/>
         <source>Test</source>
-        <translation type="unfinished"></translation>
+        <translation>Test</translation>
     </message>
     <message>
         <location filename="trafikantenwindow.cpp" line="214"/>
@@ -204,4 +199,86 @@ p, li { white-space: pre-wrap; }
         <translation>Vi beklager, men det var dessverre ikke mulig å lokalisere din posisjon for øyeblikket. Vennligst prøv igjen senere.</translation>
     </message>
 </context>
+<context>
+    <name>TravelInfoDialog</name>
+    <message>
+        <location filename="travelinfodialog.ui" line="14"/>
+        <source>Travel Info</source>
+        <translation>Reiseinformasjon</translation>
+    </message>
+</context>
+<context>
+    <name>TravelListDelegate</name>
+    <message numerus="yes">
+        <location filename="travelsearchwindow.cpp" line="229"/>
+        <source>%n switche(s)</source>
+        <translation>
+            <numerusform>%n bytte</numerusform>
+            <numerusform>% bytter</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <location filename="travelsearchwindow.cpp" line="238"/>
+        <source>%n min</source>
+        <translation>
+            <numerusform>% min</numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+</context>
+<context>
+    <name>TravelSearchWindow</name>
+    <message>
+        <location filename="travelsearchwindow.ui" line="14"/>
+        <source>Travel Search</source>
+        <translation>Reisesøk</translation>
+    </message>
+    <message>
+        <location filename="travelsearchwindow.ui" line="38"/>
+        <source>From:</source>
+        <translation>Fra:</translation>
+    </message>
+    <message>
+        <location filename="travelsearchwindow.ui" line="45"/>
+        <source>Select Departure</source>
+        <translation>Velg avreise</translation>
+    </message>
+    <message>
+        <location filename="travelsearchwindow.ui" line="52"/>
+        <source>To:</source>
+        <translation>Til:</translation>
+    </message>
+    <message>
+        <location filename="travelsearchwindow.ui" line="59"/>
+        <source>Select Destination</source>
+        <translation>Velg destinasjon</translation>
+    </message>
+    <message>
+        <location filename="travelsearchwindow.ui" line="69"/>
+        <source>Departure:</source>
+        <translation>Tidspunkt:</translation>
+    </message>
+    <message>
+        <location filename="travelsearchwindow.ui" line="78"/>
+        <source>Search</source>
+        <translation>Søk</translation>
+    </message>
+</context>
+<context>
+    <name>TravelStageListDelegate</name>
+    <message>
+        <location filename="travelinfodialog.cpp" line="95"/>
+        <source>Walking</source>
+        <translation>Gangvei</translation>
+    </message>
+    <message numerus="yes">
+        <location filename="travelinfodialog.cpp" line="108"/>
+        <location filename="travelinfodialog.cpp" line="123"/>
+        <source>%n min</source>
+        <translation>
+            <numerusform>%n min</numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+</context>
 </TS>
