@@ -10,6 +10,7 @@
 #include <qnetworkconfigmanager.h>
 #include <qnetworksession.h>
 using namespace QtMobility;
+class SearchDialog;
 namespace Ui {
     class TrafikantenWindow;
 }
@@ -29,8 +30,11 @@ private:
     Ui::TrafikantenWindow *ui;
     QGeoPositionInfoSource *positionSource;
     bool portraitMode;
+    SearchDialog* search;
 
 private slots:
+    void on_actionAbout_triggered();
+    void on_btnRouting_clicked();
     void on_btnNearby_clicked();
     void on_btnSearch_clicked();
     void positionUpdated(const QGeoPositionInfo &info);
